@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 import re
 
-def main():
+def povtas_sub():
     string = input("Insert a word: ")
     string = re.sub("r", "v", string)
     string = re.sub("R", "V", string)
